Summary:        The PARI/GP free computer algebra system
Name:           pari
Version:        2.3.5
Release:        1%{?dist}%{?pext}
License:        GPL
Group:          Applications/Engineering
Source0:        ftp://%{name}.math.u-bordeaux.fr/pub/%{name}/unix/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
Source2:        %{name}.emacs
Patch0:         %{name}-2.3.4-build.patch
URL:            http://%{name}.math.u-bordeaux.fr/
Buildroot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:         Karim Belabas <karim.belabas@math.u-bordeaux.fr>
Requires:       lib%{name} = %{version}-%{release}
Requires:       gzip tetex-xdvi
BuildRequires:  desktop-file-utils emacs tetex tetex-dvips
BuildRequires:  gmp-devel ncurses-devel readline-devel
BuildRequires:  libX11-devel

%description
PARI/GP is a widely used computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic curves...),
but also contains a large number of other useful functions to compute with
mathematical entities such as matrices, polynomials, power series, algebraic
numbers etc., and a lot of transcendental functions. This package provides gp,
an easy-to-use interactive shell giving access to the PARI functions.


%package        doc
Summary:        Documentation for PARI/GP
Group:          Documentation
Requires:       %{name} = %{version}-%{release}

%description    doc
PARI/GP is a widely used computer algebra system designed for fast computations
in number theory. This package contains its documentation in PDF and HTML format.


%package        emacs
Summary:        Emacs mode for PARI/GP
Group:          Applications/Engineering
Requires:       %{name} = %{version}-%{release}
Requires:       emacs

%description    emacs
PARI/GP is a widely used computer algebra system designed for fast computations
in number theory. This package provides the Emacs mode for PARI/GP.


%package     -n lib%{name}
Summary:        The PARI/GP core library
Group:          System Environment/Libraries

%description -n lib%{name}
The lib%{name} package contains the core library for PARI/GP.


%package     -n lib%{name}-devel
Summary:        Development tools for PARI/GP
Group:          Development/Libraries
Requires:       lib%{name} = %{version}-%{release}
Requires:       gmp-devel

%description -n lib%{name}-devel
The lib%{name}-devel package contains the static libraries and header files
for developing software using PARI/GP.


%prep
%setup -q
%patch0 -p1


%build
export CFLAGS="${RPM_OPT_FLAGS} -fPIC"

export Xincroot="%{_includedir}/X11"
export X11="%{_libdir}"

./Configure \
	--prefix=%{_prefix}             \
	--libdir=%{_libdir}             \
	--sysdatadir=%{_libdir}/%{name} \
	--mandir=%{_mandir}/man1        \
	--with-readline                 \
	--with-gmp                      \
	--graphic=X11

%{__make} %{?_smp_mflags} \
	all

# Build static library
pushd Olinux-*
%{__make} lib-sta
popd

# Build documentation
pushd doc
%{__make} html

for FILE in *.dvi; do
  %{__make} `basename ${FILE} .dvi`.pdf
done
popd


%check
%{__make} bench

# Extra tests
for TEST in compat intnum qfbsolve rfrac round4 stark; do
  %{__make} dotest-${TEST}
done


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_prefix}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/applications
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/emacs/site-lisp/site-start.d

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

desktop-file-install --vendor="%{name}"     \
	--dir=${RPM_BUILD_ROOT}%{_datadir}/applications %{SOURCE1}

%{__install} -m 0644 %{SOURCE2}             \
	${RPM_BUILD_ROOT}%{_datadir}/emacs/site-lisp/site-start.d/%{name}-init.el

%{__ln_s} %{_datadir}/%{name}/doc/users.dvi \
	${RPM_BUILD_ROOT}%{_datadir}/emacs/site-lisp/%{name}

# Install static library
pushd Olinux-*
%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install-lib-sta
popd

# Cleanup
%{__rm} -f ${RPM_BUILD_ROOT}%{_libdir}/lib*.so.?


%post -n lib%{name} -p /sbin/ldconfig


%postun -n lib%{name} -p /sbin/ldconfig


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc AUTHORS Announce* CHANGES* COMPAT COPYING INSTALL
%doc MACHINES NEW README*
%{_bindir}/gp
%{_bindir}/gp-*
%{_bindir}/gphelp
%{_bindir}/tex2mail
%{_datadir}/%{name}
%{_mandir}/man1/*.1*
%config(noreplace) %{_datadir}/applications/%{name}.desktop

%files doc
%defattr(-,root,root)
%doc doc/*.{html,pdf}

%files emacs
%defattr(-,root,root)
%{_datadir}/emacs/site-lisp/%{name}
%config(noreplace) %{_datadir}/emacs/site-lisp/site-start.d/%{name}-init.el

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/libpari-gmp.so.*

%files -n lib%{name}-devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/libpari.*a
%{_libdir}/libpari.so
%{_libdir}/%{name}


%changelog
* Wed Feb 17 2010 Peter Pramberger <peterpramb@member.fsf.org> - 2.3.5-1
- New version (2.3.5)

* Thu Jul 02 2009 Peter Pramberger <peterpramb@member.fsf.org> - 2.3.4-1
- Initial build
